# v1

你好，我计划开发一个 python 库，用于程序化连接并使用 noVNC 启动的 websockify 代理。

我已经在本地 localhost:6080 运行了一个 noVNC 测试服务，你可以进行测试。

dev/noVNC_api.py 有一个样例代码可能可以参考。

你应该自行设计库结构，对外 API 等。

# 代码风格

- 使用 async 实现，aiohttp 等
- 尽量精简，层级少，避免过度抽象

# 工作习惯

- 逐步叠加功能，从最基础的开始做好单元测试
- 可以增量记录必要的信息到你自己的 CLAUDE.md 文件中

# v2

我希望能给 client 的键盘接口添加更详细的文档和说明，类型注释，因为用户可能不知道哪些输入是合法的，特别是特殊按键？
